@@ -18,7 +18,7 @@ class PostgresClient(SQLAlchemy):
                 username (str): Username for authentication/privileges
                 password (str): Password for authentication
         """
-        super().__init__(engine = "postgres", host = host, port = port, database = database, username = username, password = password)
+        super().__init__(engine = "postgresql", host = host, port = port, database = database, username = username, password = password)
         self.engine = create_engine(self.connection_string)
 
 
